@@ -3,6 +3,7 @@ package buildtools
 import (
 	"errors"
 	"fmt"
+	"github.com/jfrog/jfrog-cli-security/utils/techutils"
 	"os"
 	"strconv"
 	"strings"
@@ -32,6 +33,7 @@ import (
 	"github.com/jfrog/jfrog-cli-security/commands/scan"
 	terraformdocs "github.com/jfrog/jfrog-cli/docs/artifactory/terraform"
 	"github.com/jfrog/jfrog-cli/docs/artifactory/terraformconfig"
+	twinedocs "github.com/jfrog/jfrog-cli/docs/artifactory/twine"
 	"github.com/jfrog/jfrog-cli/docs/buildtools/docker"
 	dotnetdocs "github.com/jfrog/jfrog-cli/docs/buildtools/dotnet"
 	"github.com/jfrog/jfrog-cli/docs/buildtools/dotnetconfig"
@@ -91,7 +93,10 @@ func GetCommands() []cli.Command {
 			SkipFlagParsing: true,
 			BashComplete:    corecommon.CreateBashCompletionFunc(),
 			Category:        buildToolsCategory,
-			Action:          MvnCmd,
+			Action: func(c *cli.Context) (err error) {
+				cmdName, _ := getCommandName(c.Args())
+				return securityCLI.WrapCmdWithCurationPostFailureRun(c, MvnCmd, techutils.Maven, cmdName)
+			},
 		},
 		{
 			Name:         "gradle-config",
@@ -208,7 +213,6 @@ func GetCommands() []cli.Command {
 		{
 			Name:            "go",
 			Flags:           cliutils.GetCommandFlags(cliutils.Go),
-			Aliases:         []string{"go"},
 			Usage:           gocommand.GetDescription(),
 			HelpName:        corecommon.CreateUsage("go", gocommand.GetDescription(), gocommand.Usage),
 			UsageText:       gocommand.GetArguments(),
@@ -216,7 +220,10 @@ func GetCommands() []cli.Command {
 			SkipFlagParsing: true,
 			BashComplete:    corecommon.CreateBashCompletionFunc(),
 			Category:        buildToolsCategory,
-			Action:          GoCmd,
+			Action: func(c *cli.Context) (err error) {
+				cmdName, _ := getCommandName(c.Args())
+				return securityCLI.WrapCmdWithCurationPostFailureRun(c, GoCmd, techutils.Go, cmdName)
+			},
 		},
 		{
 			Name:         "go-publish",
@@ -253,7 +260,10 @@ func GetCommands() []cli.Command {
 			SkipFlagParsing: true,
 			BashComplete:    corecommon.CreateBashCompletionFunc(),
 			Category:        buildToolsCategory,
-			Action:          PipCmd,
+			Action: func(c *cli.Context) (err error) {
+				cmdName, _ := getCommandName(c.Args())
+				return securityCLI.WrapCmdWithCurationPostFailureRun(c, PipCmd, techutils.Pip, cmdName)
+			},
 		},
 		{
 			Name:         "pipenv-config",
@@ -326,9 +336,13 @@ func GetCommands() []cli.Command {
 			SkipFlagParsing: true,
 			BashComplete:    corecommon.CreateBashCompletionFunc("install", "i", "isntall", "add", "ci", "publish", "p"),
 			Category:        buildToolsCategory,
-			Action: func(c *cli.Context) error {
+			Action: func(c *cli.Context) (errFromCmd error) {
 				cmdName, _ := getCommandName(c.Args())
-				return npmGenericCmd(c, cmdName, false)
+				return securityCLI.WrapCmdWithCurationPostFailureRun(c,
+					func(c *cli.Context) error {
+						return npmGenericCmd(c, cmdName, false)
+					},
+					techutils.Npm, cmdName)
 			},
 		},
 		{
@@ -389,6 +403,18 @@ func GetCommands() []cli.Command {
 			Category:        buildToolsCategory,
 			Action:          terraformCmd,
 		},
+		{
+			Name:            "twine",
+			Flags:           cliutils.GetCommandFlags(cliutils.Twine),
+			Usage:           twinedocs.GetDescription(),
+			HelpName:        corecommon.CreateUsage("twine", twinedocs.GetDescription(), twinedocs.Usage),
+			UsageText:       twinedocs.GetArguments(),
+			ArgsUsage:       common.CreateEnvVars(),
+			SkipFlagParsing: true,
+			BashComplete:    corecommon.CreateBashCompletionFunc(),
+			Category:        buildToolsCategory,
+			Action:          twineCmd,
+		},
 	})
 }
 
@@ -397,13 +423,11 @@ func MvnCmd(c *cli.Context) (err error) {
 		return err
 	}
 
-	configFilePath, exists, err := project.GetProjectConfFilePath(project.Maven)
+	configFilePath, err := getProjectConfigPathOrThrow(project.Maven, "mvn", "mvn-config")
 	if err != nil {
 		return err
 	}
-	if !exists {
-		return errors.New("no config file was found! Before running the mvn command on a project for the first time, the project should be configured with the mvn-config command")
-	}
+
 	if c.NArg() < 1 {
 		return cliutils.WrongNumberOfArgumentsHandler(c)
 	}
@@ -456,13 +480,11 @@ func GradleCmd(c *cli.Context) (err error) {
 		return err
 	}
 
-	configFilePath, exists, err := project.GetProjectConfFilePath(project.Gradle)
+	configFilePath, err := getProjectConfigPathOrThrow(project.Gradle, "gradle", "gradle-config")
 	if err != nil {
 		return err
 	}
-	if !exists {
-		return errors.New("no config file was found! Before running the gradle command on a project for the first time, the project should be configured with the gradle-config command")
-	}
+
 	// Found a config file. Continue as native command.
 	if c.NArg() < 1 {
 		return cliutils.WrongNumberOfArgumentsHandler(c)
@@ -512,13 +534,10 @@ func YarnCmd(c *cli.Context) error {
 		return err
 	}
 
-	configFilePath, exists, err := project.GetProjectConfFilePath(project.Yarn)
+	configFilePath, err := getProjectConfigPathOrThrow(project.Yarn, "yarn", "yarn-config")
 	if err != nil {
 		return err
 	}
-	if !exists {
-		return fmt.Errorf("no config file was found! Before running the yarn command on a project for the first time, the project should be configured using the yarn-config command")
-	}
 
 	yarnCmd := yarn.NewYarnCommand().SetConfigFilePath(configFilePath).SetArgs(c.Args())
 	return commands.Exec(yarnCmd)
@@ -531,15 +550,12 @@ func NugetCmd(c *cli.Context) error {
 	if c.NArg() < 1 {
 		return cliutils.WrongNumberOfArgumentsHandler(c)
 	}
-	configFilePath, exists, err := project.GetProjectConfFilePath(project.Nuget)
+
+	configFilePath, err := getProjectConfigPathOrThrow(project.Nuget, "nuget", "nuget-config")
 	if err != nil {
 		return err
 	}
 
-	if !exists {
-		return fmt.Errorf("no config file was found! Before running the nuget command on a project for the first time, the project should be configured using the nuget-config command")
-	}
-
 	rtDetails, targetRepo, useNugetV2, err := getNugetAndDotnetConfigFields(configFilePath)
 	if err != nil {
 		return err
@@ -550,9 +566,18 @@ func NugetCmd(c *cli.Context) error {
 		return err
 	}
 
+	allowInsecureConnection, err := cliutils.ExtractBoolFlagFromArgs(&filteredNugetArgs, "allow-insecure-connections")
+	if err != nil {
+		return err
+	}
+
 	nugetCmd := dotnet.NewNugetCommand()
-	nugetCmd.SetServerDetails(rtDetails).SetRepoName(targetRepo).SetBuildConfiguration(buildConfiguration).
-		SetBasicCommand(filteredNugetArgs[0]).SetUseNugetV2(useNugetV2)
+	nugetCmd.SetServerDetails(rtDetails).
+		SetRepoName(targetRepo).
+		SetBuildConfiguration(buildConfiguration).
+		SetBasicCommand(filteredNugetArgs[0]).
+		SetUseNugetV2(useNugetV2).
+		SetAllowInsecureConnections(allowInsecureConnection)
 	// Since we are using the values of the command's arguments and flags along the buildInfo collection process,
 	// we want to separate the actual NuGet basic command (restore/build...) from the arguments and flags
 	if len(filteredNugetArgs) > 1 {
@@ -571,13 +596,10 @@ func DotnetCmd(c *cli.Context) error {
 	}
 
 	// Get configuration file path.
-	configFilePath, exists, err := project.GetProjectConfFilePath(project.Dotnet)
+	configFilePath, err := getProjectConfigPathOrThrow(project.Dotnet, "dotnet", "dotnet-config")
 	if err != nil {
 		return err
 	}
-	if !exists {
-		return fmt.Errorf("no config file was found! Before running the dotnet command on a project for the first time, the project should be configured using the dotnet-config command")
-	}
 
 	rtDetails, targetRepo, useNugetV2, err := getNugetAndDotnetConfigFields(configFilePath)
 	if err != nil {
@@ -591,10 +613,15 @@ func DotnetCmd(c *cli.Context) error {
 		return err
 	}
 
+	allowInsecureConnection, err := cliutils.ExtractBoolFlagFromArgs(&filteredDotnetArgs, "allow-insecure-connections")
+	if err != nil {
+		return err
+	}
+
 	// Run command.
 	dotnetCmd := dotnet.NewDotnetCoreCliCommand()
 	dotnetCmd.SetServerDetails(rtDetails).SetRepoName(targetRepo).SetBuildConfiguration(buildConfiguration).
-		SetBasicCommand(filteredDotnetArgs[0]).SetUseNugetV2(useNugetV2)
+		SetBasicCommand(filteredDotnetArgs[0]).SetUseNugetV2(useNugetV2).SetAllowInsecureConnections(allowInsecureConnection)
 	// Since we are using the values of the command's arguments and flags along the buildInfo collection process,
 	// we want to separate the actual .NET basic command (restore/build...) from the arguments and flags
 	if len(filteredDotnetArgs) > 1 {
@@ -640,6 +667,9 @@ func extractThreadsFlag(args []string) (cleanArgs []string, threadsCount int, er
 }
 
 func GoCmd(c *cli.Context) error {
+	if show, err := cliutils.ShowCmdHelpIfNeeded(c, c.Args()); show || err != nil {
+		return err
+	}
 	configFilePath, err := goCmdVerification(c)
 	if err != nil {
 		return err
@@ -651,6 +681,9 @@ func GoCmd(c *cli.Context) error {
 }
 
 func GoPublishCmd(c *cli.Context) (err error) {
+	if show, err := cliutils.ShowCmdHelpIfNeeded(c, c.Args()); show || err != nil {
+		return err
+	}
 	configFilePath, err := goCmdVerification(c)
 	if err != nil {
 		return err
@@ -671,20 +704,15 @@ func GoPublishCmd(c *cli.Context) (err error) {
 }
 
 func goCmdVerification(c *cli.Context) (string, error) {
-	if show, err := cliutils.ShowCmdHelpIfNeeded(c, c.Args()); show || err != nil {
-		return "", err
-	}
 	if c.NArg() < 1 {
 		return "", cliutils.WrongNumberOfArgumentsHandler(c)
 	}
-	configFilePath, exists, err := project.GetProjectConfFilePath(project.Go)
+
+	configFilePath, err := getProjectConfigPathOrThrow(project.Go, "go", "go-config")
 	if err != nil {
 		return "", err
 	}
-	// Verify config file is found.
-	if !exists {
-		return "", fmt.Errorf("no config file was found! Before running the go command on a project for the first time, the project should be configured using the go-config command")
-	}
+
 	log.Debug("Go config file was found in:", configFilePath)
 	return configFilePath, nil
 }
@@ -724,7 +752,7 @@ func pullCmd(c *cli.Context, image string) error {
 	if show, err := cliutils.ShowGenericCmdHelpIfNeeded(c, c.Args(), "dockerpullhelp"); show || err != nil {
 		return err
 	}
-	_, rtDetails, _, skipLogin, filteredDockerArgs, buildConfiguration, err := commandsUtils.ExtractDockerOptionsFromArgs(c.Args())
+	_, rtDetails, _, skipLogin, filteredDockerArgs, buildConfiguration, err := extractDockerOptionsFromArgs(c.Args())
 	if err != nil {
 		return err
 	}
@@ -747,7 +775,7 @@ func pushCmd(c *cli.Context, image string) (err error) {
 	if show, err := cliutils.ShowCmdHelpIfNeeded(c, c.Args()); show || err != nil {
 		return err
 	}
-	threads, rtDetails, detailedSummary, skipLogin, filteredDockerArgs, buildConfiguration, err := commandsUtils.ExtractDockerOptionsFromArgs(c.Args())
+	threads, rtDetails, detailedSummary, skipLogin, filteredDockerArgs, buildConfiguration, err := extractDockerOptionsFromArgs(c.Args())
 	if err != nil {
 		return
 	}
@@ -780,7 +808,7 @@ func dockerNativeCmd(c *cli.Context) error {
 	if show, err := cliutils.ShowCmdHelpIfNeeded(c, c.Args()); show || err != nil {
 		return err
 	}
-	_, _, _, _, cleanArgs, _, err := commandsUtils.ExtractDockerOptionsFromArgs(c.Args())
+	_, _, _, _, cleanArgs, _, err := extractDockerOptionsFromArgs(c.Args())
 	if err != nil {
 		return err
 	}
@@ -788,6 +816,34 @@ func dockerNativeCmd(c *cli.Context) error {
 	return cm.RunNativeCmd(cleanArgs)
 }
 
+// Remove all the none docker CLI flags from args.
+func extractDockerOptionsFromArgs(args []string) (threads int, serverDetails *coreConfig.ServerDetails, detailedSummary, skipLogin bool, cleanArgs []string, buildConfig *build.BuildConfiguration, err error) {
+	cleanArgs = append([]string(nil), args...)
+	var serverId string
+	cleanArgs, serverId, err = coreutils.ExtractServerIdFromCommand(cleanArgs)
+	if err != nil {
+		return
+	}
+	serverDetails, err = coreConfig.GetSpecificConfig(serverId, true, true)
+	if err != nil {
+		return
+	}
+	cleanArgs, threads, err = coreutils.ExtractThreadsFromArgs(cleanArgs, 3)
+	if err != nil {
+		return
+	}
+	cleanArgs, detailedSummary, err = coreutils.ExtractDetailedSummaryFromArgs(cleanArgs)
+	if err != nil {
+		return
+	}
+	cleanArgs, skipLogin, err = coreutils.ExtractSkipLoginFromArgs(cleanArgs)
+	if err != nil {
+		return
+	}
+	cleanArgs, buildConfig, err = build.ExtractBuildDetailsFromArgs(cleanArgs)
+	return
+}
+
 // Assuming command name is the first argument that isn't a flag.
 // Returns the command name, and the filtered arguments slice without it.
 func getCommandName(orgArgs []string) (string, []string) {
@@ -832,6 +888,7 @@ func npmGenericCmd(c *cli.Context, cmdName string, collectBuildInfoIfRequested b
 
 	// Run generic npm command.
 	npmCmd := npm.NewNpmCommand(cmdName, collectBuildInfoIfRequested)
+
 	configFilePath, args, err := GetNpmConfigAndArgs(c)
 	if err != nil {
 		return err
@@ -873,13 +930,9 @@ func NpmPublishCmd(c *cli.Context) (err error) {
 }
 
 func GetNpmConfigAndArgs(c *cli.Context) (configFilePath string, args []string, err error) {
-	configFilePath, exists, err := project.GetProjectConfFilePath(project.Npm)
+	configFilePath, err = getProjectConfigPathOrThrow(project.Npm, "npm", "npm-config")
 	if err != nil {
-		return "", nil, err
-	}
-
-	if !exists {
-		return "", nil, errorutils.CheckErrorf("no config file was found! Before running the npm command on a project for the first time, the project should be configured using the npm-config command")
+		return
 	}
 	_, args = getCommandName(c.Args())
 	return
@@ -922,19 +975,20 @@ func pythonCmd(c *cli.Context, projectType project.ProjectType) error {
 	cmdName, filteredArgs := getCommandName(orgArgs)
 	switch projectType {
 	case project.Pip:
-		pythonCommand := python.NewPipCommand()
-		pythonCommand.SetServerDetails(rtDetails).SetRepo(pythonConfig.TargetRepo()).SetCommandName(cmdName).SetArgs(filteredArgs)
-		return commands.Exec(pythonCommand)
+		pipCommand := python.NewPipCommand()
+		pipCommand.SetServerDetails(rtDetails).SetRepo(pythonConfig.TargetRepo()).SetCommandName(cmdName).SetArgs(filteredArgs)
+		return commands.Exec(pipCommand)
 	case project.Pipenv:
-		pythonCommand := python.NewPipenvCommand()
-		pythonCommand.SetServerDetails(rtDetails).SetRepo(pythonConfig.TargetRepo()).SetCommandName(cmdName).SetArgs(filteredArgs)
-		return commands.Exec(pythonCommand)
+		pipenvCommand := python.NewPipenvCommand()
+		pipenvCommand.SetServerDetails(rtDetails).SetRepo(pythonConfig.TargetRepo()).SetCommandName(cmdName).SetArgs(filteredArgs)
+		return commands.Exec(pipenvCommand)
 	case project.Poetry:
-		pythonCommand := python.NewPoetryCommand()
-		pythonCommand.SetServerDetails(rtDetails).SetRepo(pythonConfig.TargetRepo()).SetCommandName(cmdName).SetArgs(filteredArgs)
-		return commands.Exec(pythonCommand)
+		poetryCommand := python.NewPoetryCommand()
+		poetryCommand.SetServerDetails(rtDetails).SetRepo(pythonConfig.TargetRepo()).SetCommandName(cmdName).SetArgs(filteredArgs)
+		return commands.Exec(poetryCommand)
+	default:
+		return errorutils.CheckErrorf("%s is not supported", projectType)
 	}
-	return errorutils.CheckErrorf("%s is not supported", projectType)
 }
 
 func terraformCmd(c *cli.Context) error {
@@ -956,13 +1010,9 @@ func terraformCmd(c *cli.Context) error {
 }
 
 func getTerraformConfigAndArgs(c *cli.Context) (configFilePath string, args []string, err error) {
-	configFilePath, exists, err := project.GetProjectConfFilePath(project.Terraform)
+	configFilePath, err = getProjectConfigPathOrThrow(project.Terraform, "terraform", "terraform-config")
 	if err != nil {
-		return "", nil, err
-	}
-
-	if !exists {
-		return "", nil, errors.New("no config file was found! Before running the terraform command on a project for the first time, the project should be configured using the terraform-config command")
+		return
 	}
 	args = cliutils.ExtractCommand(c)
 	return
@@ -978,3 +1028,63 @@ func terraformPublishCmd(configFilePath string, args []string, c *cli.Context) e
 	result := terraformCmd.Result()
 	return cliutils.PrintBriefSummaryReport(result.SuccessCount(), result.FailCount(), cliutils.IsFailNoOp(c), err)
 }
+
+func getProjectConfigPathOrThrow(projectType project.ProjectType, cmdName, configCmdName string) (configFilePath string, err error) {
+	configFilePath, exists, err := project.GetProjectConfFilePath(projectType)
+	if err != nil {
+		return
+	}
+	if !exists {
+		return "", errorutils.CheckErrorf(getMissingConfigErrMsg(cmdName, configCmdName))
+	}
+	return
+}
+
+func getMissingConfigErrMsg(cmdName, configCmdName string) string {
+	return fmt.Sprintf("no config file was found! Before running the 'jf %s' command on a project for the first time, the project should be configured with the 'jf %s' command", cmdName, configCmdName)
+}
+
+func twineCmd(c *cli.Context) error {
+	if show, err := cliutils.ShowCmdHelpIfNeeded(c, c.Args()); show || err != nil {
+		return err
+	}
+	serverDetails, targetRepo, err := getTwineConfigAndArgs()
+	if err != nil {
+		return err
+	}
+	cmdName, filteredArgs := getCommandName(cliutils.ExtractCommand(c))
+	return python.NewTwineCommand(cmdName).SetServerDetails(serverDetails).SetTargetRepo(targetRepo).SetArgs(filteredArgs).Run()
+}
+
+func getTwineConfigAndArgs() (serverDetails *coreConfig.ServerDetails, targetRepo string, err error) {
+	configFilePath, err := getTwineConfigPath()
+	if err != nil {
+		return
+	}
+
+	vConfig, err := project.ReadConfigFile(configFilePath, project.YAML)
+	if err != nil {
+		return nil, "", fmt.Errorf("failed while reading configuration file '%s'. Error: %s", configFilePath, err.Error())
+	}
+	projectConfig, err := project.GetRepoConfigByPrefix(configFilePath, project.ProjectConfigDeployerPrefix, vConfig)
+	if err != nil {
+		return nil, "", err
+	}
+	serverDetails, err = projectConfig.ServerDetails()
+	if err != nil {
+		return nil, "", err
+	}
+	targetRepo = projectConfig.TargetRepo()
+	return
+}
+
+func getTwineConfigPath() (configFilePath string, err error) {
+	var exists bool
+	for _, projectType := range []project.ProjectType{project.Pip, project.Pipenv} {
+		configFilePath, exists, err = project.GetProjectConfFilePath(projectType)
+		if err != nil || exists {
+			return
+		}
+	}
+	return "", errorutils.CheckErrorf(getMissingConfigErrMsg("twine", "pip-config OR pipenv-config"))
+}
