@@ -1,11 +1,14 @@
 package releasebundlecreate
 
-const Description = "Create a release bundle."
+var Usage = []string{"ds rbc [command options] <release bundle name> <release bundle version> <pattern>",
+	"ds rbc --spec=<File Spec path> [command options] <release bundle name> <release bundle version>"}
 
-var Usage = []string{"jfrog rt rbc [command options] <release bundle name> <release bundle version> <pattern>",
-	"jfrog rt rbc --spec=<File Spec path> [command options] <release bundle name> <release bundle version>"}
+func GetDescription() string {
+	return "Create a release bundle v1."
+}
 
-const Arguments string = `	release bundle name
+func GetArguments() string {
+	return `	release bundle name
 		The name of the release bundle.
 
 	release bundle version
@@ -14,3 +17,4 @@ const Arguments string = `	release bundle name
 	pattern
 		Specifies the source path in Artifactory, from which the artifacts should be bundled,
 		in the following format: <repository name>/<repository path>. You can use wildcards to specify multiple artifacts.`
+}
