@@ -3,7 +3,7 @@ package transferconfig
 var Usage = []string{"rt transfer-config [command options] <source-server-id> <target-server-id>"}
 
 func GetDescription() string {
-	return "Copy full Artifactory configuration from source Artifactory server to target Artifactory server. Warning - This action will wipe all Artifactory content in this target server."
+	return `Copy full Artifactory configuration from source Artifactory server to target Artifactory server.`
 }
 
 func GetArguments() string {
@@ -11,5 +11,6 @@ func GetArguments() string {
 		The source server ID. The configuration will be exported from this server.
 
 	target-server-id
-		The target server ID. The configuration will be imported to this server.`
+		The target server ID. The configuration will be imported to this server.
+		[Warning] This action will wipe all Artifactory content in this target server.`
 }
