@@ -2,6 +2,8 @@ package main
 
 import (
 	"fmt"
+	"github.com/jfrog/jfrog-cli-core/v2/artifactory/commands/generic"
+	"github.com/jfrog/jfrog-cli-core/v2/artifactory/utils"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -82,6 +84,7 @@ func testNpm(t *testing.T, isLegacy bool) {
 		assert.NoError(t, err)
 		return
 	}
+	log.Info("npm version:", npmVersion.GetVersion())
 	isNpm7 := isNpm7(npmVersion)
 
 	// Temporarily change the cache folder to a temporary folder - to make sure the cache is clean and dependencies will be downloaded from Artifactory
@@ -372,7 +375,7 @@ func validateNpmCommonPublish(t *testing.T, npmTestParams npmTestParams, isNpm7,
 	}
 	buildInfo := publishedBuildInfo.BuildInfo
 	expectedArtifactName := tests.GetNpmArtifactName(isNpm7, isScoped)
-	if buildInfo.Modules == nil || len(buildInfo.Modules) == 0 {
+	if len(buildInfo.Modules) == 0 {
 		// Case no module was created
 		assert.Fail(t, "npm publish test failed", "params: \n%v \nexpected to have module with the following artifact: \n%v \nbut has no modules: \n%v",
 			npmTestParams, expectedArtifactName, buildInfo)
@@ -460,6 +463,48 @@ func TestNpmPublishDetailedSummary(t *testing.T) {
 	assert.Equal(t, 64, len(files[0].Sha256), "Summary validation failed - sha256 should be in size 64 digits.")
 }
 
+func TestNpmDistTag(t *testing.T) {
+	initNpmTest(t)
+	defer cleanNpmTest(t)
+	wd, err := os.Getwd()
+	assert.NoError(t, err, "Failed to get current dir")
+	npmPath := initNpmProjectTest(t)
+	chdirCallBack := clientTestUtils.ChangeDirWithCallback(t, wd, npmPath)
+	defer chdirCallBack()
+
+	jfrogCli := coretests.NewJfrogCli(execMain, "jfrog", "")
+
+	// Publish package with tag.
+	tagP := "tag-from-publish"
+	assert.NoError(t, jfrogCli.Exec("npm", "p", "--tag="+tagP))
+
+	// Add tag using dist-tag add command.
+	tagDt := "tag-from-dist-tag"
+	assert.NoError(t, jfrogCli.Exec("npm", "dist-tag", "add", "jfrog-cli-tests@v1.0.0", tagDt))
+
+	assertDistTagsExist(t, []string{tagP, tagDt, "latest"})
+}
+
+func assertDistTagsExist(t *testing.T, expectedTags []string) {
+	searchSpecBuilder := spec.NewBuilder().Pattern(tests.NpmRepo + "/*jfrog-cli-tests*1.0.0.tgz").Recursive(true)
+	searchCmd := generic.NewSearchCommand()
+	searchCmd.SetServerDetails(serverDetails)
+	searchCmd.SetSpec(searchSpecBuilder.BuildSpec())
+
+	reader, err := searchCmd.Search()
+	assert.NoError(t, err)
+	readerGetErrorAndAssert(t, reader)
+	defer readerCloseAndAssert(t, reader)
+	length, err := reader.Length()
+	assert.NoError(t, err)
+	if !assert.Equal(t, length, 1) {
+		return
+	}
+	for resultItem := new(utils.SearchResult); reader.NextRecord(resultItem) == nil; resultItem = new(utils.SearchResult) {
+		assert.ElementsMatch(t, resultItem.Props[npm.DistTagPropKey], expectedTags)
+	}
+}
+
 func TestNpmPublishWithDeploymentView(t *testing.T) {
 	initNpmTest(t)
 	defer cleanNpmTest(t)
@@ -549,20 +594,7 @@ func TestNpmPublishWithWorkspaces(t *testing.T) {
 	err = commands.Exec(npmpCmd)
 	assert.NoError(t, err)
 
-	result := npmpCmd.Result()
-	assert.NotNil(t, result)
-	reader := result.Reader()
-	readerGetErrorAndAssert(t, reader)
-	defer readerCloseAndAssert(t, reader)
-	// Read result
-	var files []clientutils.FileTransferDetails
-	for transferDetails := new(clientutils.FileTransferDetails); reader.NextRecord(transferDetails) == nil; transferDetails = new(clientutils.FileTransferDetails) {
-		files = append(files, *transferDetails)
-	}
-	if files == nil {
-		assert.NotNil(t, files)
-		return
-	}
+	files := assertNpmPublishResultFiles(t, npmpCmd)
 
 	expectedTars := []string{"nested1", "nested2"}
 	for index, tar := range expectedTars {
@@ -577,6 +609,51 @@ func TestNpmPublishWithWorkspaces(t *testing.T) {
 	}
 }
 
+// Test npm publish command with provided tarball
+func TestNpmPackProvidedTarball(t *testing.T) {
+	// Check npm version
+	npmVersion, _, err := buildutils.GetNpmVersionAndExecPath(log.Logger)
+	if err != nil {
+		assert.NoError(t, err)
+		return
+	}
+	// In npm under v7 skip test
+	if npmVersion.Compare(minimumWorkspacesNpmVersion) > 0 {
+		log.Info("Test skipped as this function in not supported in npm version " + npmVersion.GetVersion())
+		return
+	}
+
+	// Prepare test
+	initNpmTest(t)
+	defer cleanNpmTest(t)
+	tempDirPath, createTempDirCallback := coretests.CreateTempDirWithCallbackAndAssert(t)
+	defer createTempDirCallback()
+	testFolder := filepath.Join(filepath.FromSlash(tests.GetTestResourcesPath()), "npm", "npmprovidedtarball")
+	err = biutils.CopyDir(testFolder, tempDirPath, false, []string{})
+	assert.NoError(t, err)
+
+	// CD inside the copied project and create npm config
+	wd, err := os.Getwd()
+	assert.NoError(t, err)
+	chdirCallback := clientTestUtils.ChangeDirWithCallback(t, wd, tempDirPath)
+	defer chdirCallback()
+	err = createConfigFileForTest([]string{tempDirPath}, tests.NpmRemoteRepo, tests.NpmRepo, t, project.Npm, false)
+	assert.NoError(t, err)
+
+	// Init npm project & npmp command for testing
+	configFilePath := filepath.Join(tempDirPath, ".jfrog", "projects", "npm.yaml")
+	args := []string{"jfrog-cli-tests-v1.0.0.tgz", "--detailed-summary=true", "--workspaces", "--verbose"}
+	npmpCmd := npm.NewNpmPublishCommand()
+	npmpCmd.SetConfigFilePath(configFilePath).SetArgs(args)
+	npmpCmd.SetNpmArgs(args)
+	assert.NoError(t, npmpCmd.Init())
+	err = commands.Exec(npmpCmd)
+	assert.NoError(t, err)
+
+	// Check result
+	assertNpmPublishResultFiles(t, npmpCmd)
+}
+
 func TestYarn(t *testing.T) {
 	initNpmTest(t)
 	defer cleanNpmTest(t)
@@ -679,3 +756,16 @@ func runGenericNpm(t *testing.T, args ...string) {
 	jfCli := coretests.NewJfrogCli(execMain, "jf", "")
 	assert.NoError(t, jfCli.WithoutCredentials().Exec(args...))
 }
+
+func assertNpmPublishResultFiles(t *testing.T, npmpCmd *npm.NpmPublishCommand) (files []clientutils.FileTransferDetails) {
+	result := npmpCmd.Result()
+	assert.NotNil(t, result)
+	reader := result.Reader()
+	readerGetErrorAndAssert(t, reader)
+	defer readerCloseAndAssert(t, reader)
+	for transferDetails := new(clientutils.FileTransferDetails); reader.NextRecord(transferDetails) == nil; transferDetails = new(clientutils.FileTransferDetails) {
+		files = append(files, *transferDetails)
+	}
+	assert.NotNil(t, files)
+	return files
+}
