@@ -1,11 +1,14 @@
 package cliutils
 
 import (
-	"github.com/codegangsta/cli"
-	"github.com/jfrog/jfrog-client-go/utils"
+	"golang.org/x/exp/slices"
 	"sort"
 	"strconv"
 	"strings"
+
+	commonCliUtils "github.com/jfrog/jfrog-cli-core/v2/common/cliutils"
+	"github.com/jfrog/jfrog-client-go/utils"
+	"github.com/urfave/cli"
 )
 
 func GetIntFlagValue(c *cli.Context, flagName string, defValue int) (int, error) {
@@ -19,17 +22,17 @@ func GetIntFlagValue(c *cli.Context, flagName string, defValue int) (int, error)
 
 func GetStringsArrFlagValue(c *cli.Context, flagName string) (resultArray []string) {
 	if c.IsSet(flagName) {
-		for _, singleValue := range strings.Split(c.String(flagName), ";") {
-			resultArray = append(resultArray, singleValue)
-		}
+		resultArray = append(resultArray, strings.Split(c.String(flagName), ";")...)
 	}
 	return
 }
 
-func ExtractCommand(c *cli.Context) (command []string) {
-	command = make([]string, len(c.Args()))
-	copy(command, c.Args())
-	return command
+func GetThreadsCount(c *cli.Context) (threads int, err error) {
+	return commonCliUtils.GetThreadsCount(c.String("threads"))
+}
+
+func ExtractCommand(c *cli.Context) []string {
+	return slices.Clone(c.Args())
 }
 
 func GetSortedCommands(commands cli.CommandsByName) cli.CommandsByName {
