@@ -37,6 +37,8 @@ const (
 	GitLfsClean            = "git-lfs-clean"
 	Mvn                    = "mvn"
 	MvnConfig              = "mvn-config"
+	CocoapodsConfig        = "cocoapods-config"
+	SwiftConfig            = "swift-config"
 	Gradle                 = "gradle"
 	GradleConfig           = "gradle-config"
 	DockerPromote          = "docker-promote"
@@ -66,6 +68,7 @@ const (
 	PipConfig              = "pip-config"
 	TerraformConfig        = "terraform-config"
 	Terraform              = "terraform"
+	Twine                  = "twine"
 	Pipenv                 = "pipenv"
 	PipenvConfig           = "pipenv-config"
 	PipenvInstall          = "pipenv-install"
@@ -123,6 +126,8 @@ const (
 	ReleaseBundleDistribute   = "release-bundle-distribute"
 	ReleaseBundleDeleteLocal  = "release-bundle-delete-local"
 	ReleaseBundleDeleteRemote = "release-bundle-delete-remote"
+	ReleaseBundleExport       = "release-bundle-export"
+	ReleaseBundleImport       = "release-bundle-import"
 
 	// Access Token Create commands keys
 	AccessTokenCreate = "access-token-create"
@@ -196,6 +201,7 @@ const (
 	Status                  = "status"
 	MinSplit                = "min-split"
 	SplitCount              = "split-count"
+	ChunkSize               = "chunk-size"
 
 	// Config flags
 	interactive   = "interactive"
@@ -370,7 +376,8 @@ const (
 	npmDetailedSummary = npmPrefix + detailedSummary
 
 	// Unique nuget/dotnet config flags
-	nugetV2 = "nuget-v2"
+	nugetV2                  = "nuget-v2"
+	allowInsecureConnections = "allow-insecure-connections"
 
 	// Unique go flags
 	noFallback = "no-fallback"
@@ -528,9 +535,6 @@ const (
 	Completion = "completion"
 	Install    = "install"
 
-	// Setup flags
-	setupFormat = "setup-format"
-
 	// *** TransferFiles Commands' flags ***
 	transferFilesPrefix = "transfer-files-"
 	Filestore           = "filestore"
@@ -589,7 +593,7 @@ var flagsMap = map[string]cli.Flag{
 	// Common commands flags
 	platformUrl: cli.StringFlag{
 		Name:  url,
-		Usage: "[Optional] JFrog platform URL.` `",
+		Usage: "[Optional] JFrog platform URL. (example: https://acme.jfrog.io)` `",
 	},
 	user: cli.StringFlag{
 		Name:  user,
@@ -605,7 +609,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	serverId: cli.StringFlag{
 		Name:  serverId,
-		Usage: "[Optional] Server ID configured using the config command.` `",
+		Usage: "[Optional] Server ID configured using the 'jf config' command.` `",
 	},
 	passwordStdin: cli.BoolFlag{
 		Name:  passwordStdin,
@@ -618,7 +622,7 @@ var flagsMap = map[string]cli.Flag{
 	// Artifactory's commands flags
 	url: cli.StringFlag{
 		Name:  url,
-		Usage: "[Optional] JFrog Artifactory URL.` `",
+		Usage: "[Optional] JFrog Artifactory URL. (example: https://acme.jfrog.io/artifactory)` `",
 	},
 	sshKeyPath: cli.StringFlag{
 		Name:  sshKeyPath,
@@ -638,7 +642,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	sortBy: cli.StringFlag{
 		Name:  sortBy,
-		Usage: fmt.Sprintf("[Optional] A list of semicolon-separated fields to sort by. The fields must be part of the 'items' AQL domain. For more information, see %sjfrog-artifactory-documentation/artifactory-query-language` `", coreutils.JFrogHelpUrl),
+		Usage: fmt.Sprintf("[Optional] List of semicolon-separated(;) fields to sort by. The fields must be part of the 'items' AQL domain. For more information, see %sjfrog-artifactory-documentation/artifactory-query-language` `", coreutils.JFrogHelpUrl),
 	},
 	sortOrder: cli.StringFlag{
 		Name:  sortOrder,
@@ -658,7 +662,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	specVars: cli.StringFlag{
 		Name:  specVars,
-		Usage: "[Optional] List of variables in the form of \"key1=value1;key2=value2;...\" (wrapped by quotes) to be replaced in the File Spec. In the File Spec, the variables should be used as follows: ${key1}.` `",
+		Usage: "[Optional] List of semicolon-separated(;) variables in the form of \"key1=value1;key2=value2;...\" (wrapped by quotes) to be replaced in the File Spec. In the File Spec, the variables should be used as follows: ${key1}.` `",
 	},
 	buildName: cli.StringFlag{
 		Name:  buildName,
@@ -674,11 +678,11 @@ var flagsMap = map[string]cli.Flag{
 	},
 	exclusions: cli.StringFlag{
 		Name:  exclusions,
-		Usage: "[Optional] Semicolon-separated list of exclusions. Exclusions can include the * and the ? wildcards.` `",
+		Usage: "[Optional] List of semicolon-separated(;) exclusions. Exclusions can include the * and the ? wildcards.` `",
 	},
 	uploadExclusions: cli.StringFlag{
 		Name:  exclusions,
-		Usage: "[Optional] Semicolon-separated list of exclude patterns. Exclude patterns may contain the * and the ? wildcards or a regex pattern, according to the value of the 'regexp' option.` `",
+		Usage: "[Optional] List of semicolon-separated(;) exclude patterns. Exclude patterns may contain the * and the ? wildcards or a regex pattern, according to the value of the 'regexp' option.` `",
 	},
 	build: cli.StringFlag{
 		Name:  build,
@@ -711,7 +715,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	retryWaitTime: cli.StringFlag{
 		Name:  retryWaitTime,
-		Usage: "[Default: 0] Number of seconds or milliseconds to wait between retries. The numeric value should either end with s for seconds or ms for milliseconds.` `",
+		Usage: "[Default: 0] Number of seconds or milliseconds to wait between retries. The numeric value should either end with s for seconds or ms for milliseconds (for example: 10s or 100ms).` `",
 	},
 	InsecureTls: cli.BoolFlag{
 		Name:  InsecureTls,
@@ -727,7 +731,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	archiveEntries: cli.StringFlag{
 		Name:  archiveEntries,
-		Usage: "[Optional] If specified, only archive artifacts containing entries matching this pattern are matched. You can use wildcards to specify multiple artifacts.` `",
+		Usage: "[Optional] This option is no longer supported since version 7.90.5 of Artifactory. If specified, only archive artifacts containing entries matching this pattern are matched. You can use wildcards to specify multiple artifacts.` `",
 	},
 	detailedSummary: cli.BoolFlag{
 		Name:  detailedSummary,
@@ -785,7 +789,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	uploadTargetProps: cli.StringFlag{
 		Name:  targetProps,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Those properties will be attached to the uploaded artifacts.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Those properties will be attached to the uploaded artifacts.` `",
 	},
 	uploadSyncDeletes: cli.StringFlag{
 		Name:  syncDeletes,
@@ -793,15 +797,19 @@ var flagsMap = map[string]cli.Flag{
 	},
 	uploadArchive: cli.StringFlag{
 		Name:  archive,
-		Usage: "[Optional] Set to \"zip\" to deploy the files to Artifactory in a ZIP archive.` `",
+		Usage: "[Optional] Set to \"zip\" to pack and deploy the files to Artifactory inside a ZIP archive. Currently, the only packaging format supported is zip.` `",
 	},
 	uploadMinSplit: cli.StringFlag{
 		Name:  MinSplit,
-		Usage: "[Default: " + strconv.Itoa(UploadMinSplitMb) + "] The minimum file size in MiB required to attempt a multi-part upload. This option, as well as the functionality of multi-part upload, requires Artifactory with S3 storage.` `",
+		Usage: "[Default: " + strconv.Itoa(UploadMinSplitMb) + "] The minimum file size in MiB required to attempt a multi-part upload. This option, as well as the functionality of multi-part upload, requires Artifactory with S3 or GCP storage.` `",
 	},
 	uploadSplitCount: cli.StringFlag{
 		Name:  SplitCount,
-		Usage: "[Default: " + strconv.Itoa(UploadSplitCount) + "] The maximum number of parts that can be concurrently uploaded per file during a multi-part upload. Set to 0 to disable multi-part upload. This option, as well as the functionality of multi-part upload, requires Artifactory with S3 storage.` `",
+		Usage: "[Default: " + strconv.Itoa(UploadSplitCount) + "] The maximum number of parts that can be concurrently uploaded per file during a multi-part upload. Set to 0 to disable multi-part upload. This option, as well as the functionality of multi-part upload, requires Artifactory with S3 or GCP storage.` `",
+	},
+	ChunkSize: cli.StringFlag{
+		Name:  ChunkSize,
+		Usage: "[Default: " + strconv.Itoa(UploadChunkSizeMb) + "] The upload chunk size in MiB that can be concurrently uploaded during a multi-part upload. This option, as well as the functionality of multi-part upload, requires Artifactory with S3 or GCP storage.` `",
 	},
 	syncDeletesQuiet: cli.BoolFlag{
 		Name:  quiet,
@@ -843,11 +851,11 @@ var flagsMap = map[string]cli.Flag{
 	},
 	downloadProps: cli.StringFlag{
 		Name:  props,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts with these properties will be downloaded.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts with these properties will be downloaded.` `",
 	},
 	downloadExcludeProps: cli.StringFlag{
 		Name:  excludeProps,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts without the specified properties will be downloaded.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts without the specified properties will be downloaded.` `",
 	},
 	downloadSyncDeletes: cli.StringFlag{
 		Name:  syncDeletes,
@@ -863,11 +871,11 @@ var flagsMap = map[string]cli.Flag{
 	},
 	moveProps: cli.StringFlag{
 		Name:  props,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts with these properties will be moved.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts with these properties will be moved.` `",
 	},
 	moveExcludeProps: cli.StringFlag{
 		Name:  excludeProps,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts without the specified properties will be moved.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts without the specified properties will be moved.` `",
 	},
 	copyRecursive: cli.BoolTFlag{
 		Name:  recursive,
@@ -879,11 +887,11 @@ var flagsMap = map[string]cli.Flag{
 	},
 	copyProps: cli.StringFlag{
 		Name:  props,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts with these properties will be copied.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts with these properties will be copied.` `",
 	},
 	copyExcludeProps: cli.StringFlag{
 		Name:  excludeProps,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts without the specified properties will be copied.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts without the specified properties will be copied.` `",
 	},
 	deleteRecursive: cli.BoolTFlag{
 		Name:  recursive,
@@ -891,11 +899,11 @@ var flagsMap = map[string]cli.Flag{
 	},
 	deleteProps: cli.StringFlag{
 		Name:  props,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts with these properties will be deleted.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts with these properties will be deleted.` `",
 	},
 	deleteExcludeProps: cli.StringFlag{
 		Name:  excludeProps,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts without the specified properties will be deleted.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts without the specified properties will be deleted.` `",
 	},
 	deleteQuiet: cli.BoolFlag{
 		Name:  quiet,
@@ -911,11 +919,11 @@ var flagsMap = map[string]cli.Flag{
 	},
 	searchProps: cli.StringFlag{
 		Name:  props,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts with these properties will be returned.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts with these properties will be returned.` `",
 	},
 	searchExcludeProps: cli.StringFlag{
 		Name:  excludeProps,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts without the specified properties will be returned` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts without the specified properties will be returned` `",
 	},
 	searchTransitive: cli.BoolFlag{
 		Name:  transitive,
@@ -923,7 +931,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	searchInclude: cli.StringFlag{
 		Name:  searchInclude,
-		Usage: fmt.Sprintf("[Optional] List of fields in the form of \"value1;value2;...\". Only the path and the fields that are specified will be returned. The fields must be part of the 'items' AQL domain. For the full supported items list, check %sjfrog-artifactory-documentation/artifactory-query-language` `", coreutils.JFrogHelpUrl),
+		Usage: fmt.Sprintf("[Optional] List of semicolon-separated(;) fields in the form of \"value1;value2;...\". Only the path and the fields that are specified will be returned. The fields must be part of the 'items' AQL domain. For the full supported items list, check %sjfrog-artifactory-documentation/artifactory-query-language` `", coreutils.JFrogHelpUrl),
 	},
 	propsRecursive: cli.BoolTFlag{
 		Name:  recursive,
@@ -931,11 +939,11 @@ var flagsMap = map[string]cli.Flag{
 	},
 	propsProps: cli.StringFlag{
 		Name:  props,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts with these properties are affected.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts with these properties are affected.` `",
 	},
 	propsExcludeProps: cli.StringFlag{
 		Name:  excludeProps,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". Only artifacts without the specified properties are affected` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\". Only artifacts without the specified properties are affected` `",
 	},
 	buildUrl: cli.StringFlag{
 		Name:  buildUrl,
@@ -1019,7 +1027,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	bprProps: cli.StringFlag{
 		Name:  props,
-		Usage: "[Optional] List of properties in the form of \"key1=value1;key2=value2,...\". A list of properties to attach to the build artifacts.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties in the form of \"key1=value1;key2=value2;...\" to be attached to the build artifacts.` `",
 	},
 	targetDockerImage: cli.StringFlag{
 		Name:  "target-docker-image",
@@ -1047,7 +1055,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	excludeBuilds: cli.StringFlag{
 		Name:  excludeBuilds,
-		Usage: "[Optional] List of build numbers in the form of \"value1,value2,...\", that should not be removed from Artifactory.` `",
+		Usage: "[Optional] List of comma-separated(,) build numbers in the form of \"value1,value2,...\", that should not be removed from Artifactory.` `",
 	},
 	deleteArtifacts: cli.BoolFlag{
 		Name:  deleteArtifacts,
@@ -1059,7 +1067,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	refs: cli.StringFlag{
 		Name:  refs,
-		Usage: "[Default: refs/remotes/*] List of Git references in the form of \"ref1,ref2,...\" which should be preserved.` `",
+		Usage: "[Default: refs/remotes/*] List of comma-separated(,) Git references in the form of \"ref1,ref2,...\" which should be preserved.` `",
 	},
 	glcRepo: cli.StringFlag{
 		Name:  repo,
@@ -1154,6 +1162,10 @@ var flagsMap = map[string]cli.Flag{
 		Name:  nugetV2,
 		Usage: "[Default: false] Set to true if you'd like to use the NuGet V2 protocol when restoring packages from Artifactory.` `",
 	},
+	allowInsecureConnections: cli.BoolFlag{
+		Name:  allowInsecureConnections,
+		Usage: "[Default: false] Set to true if you wish to configure NuGet sources with unsecured connections. This is recommended for testing purposes only. ` `",
+	},
 	noFallback: cli.BoolTFlag{
 		Name:  noFallback,
 		Usage: "[Default: false] Set to true to avoid downloading packages from the VCS, if they are missing in Artifactory.` `",
@@ -1172,11 +1184,11 @@ var flagsMap = map[string]cli.Flag{
 	},
 	vars: cli.StringFlag{
 		Name:  vars,
-		Usage: "[Optional] List of variables in the form of \"key1=value1;key2=value2;...\" (wrapped by quotes) to be replaced in the template. In the template, the variables should be used as follows: ${key1}.` `",
+		Usage: "[Optional] List of semicolon-separated(;) variables in the form of \"key1=value1;key2=value2;...\" (wrapped by quotes) to be replaced in the template. In the template, the variables should be used as follows: ${key1}.` `",
 	},
 	rtAtcGroups: cli.StringFlag{
 		Name: Groups,
-		Usage: "[Default: *] A list of comma-separated groups for the access token to be associated with. " +
+		Usage: "[Default: *] A list of comma-separated(,) groups for the access token to be associated with. " +
 			"Specify * to indicate that this is a 'user-scoped token', i.e., the token provides the same access privileges that the current subject has, and is therefore evaluated dynamically. " +
 			"A non-admin user can only provide a scope that is a subset of the groups to which he belongs` `",
 	},
@@ -1194,7 +1206,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	rtAtcAudience: cli.StringFlag{
 		Name:  Audience,
-		Usage: "[Optional] A space-separate list of the other Artifactory instances or services that should accept this token identified by their Artifactory Service IDs, as obtained by the 'jfrog rt curl api/system/service_id' command.` `",
+		Usage: "[Optional] A space-separated list of the other Artifactory instances or services that should accept this token identified by their Artifactory Service IDs, as obtained by the 'jfrog rt curl api/system/service_id' command.` `",
 	},
 	usersCreateCsv: cli.StringFlag{
 		Name:  csv,
@@ -1206,7 +1218,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	UsersGroups: cli.StringFlag{
 		Name:  UsersGroups,
-		Usage: "[Optional] A list of comma-separated groups for the new users to be associated with.` `",
+		Usage: "[Optional] A list of comma-separated(,) groups for the new users to be associated with.` `",
 	},
 	Replace: cli.BoolFlag{
 		Name:  Replace,
@@ -1240,7 +1252,7 @@ var flagsMap = map[string]cli.Flag{
 	// Distribution's commands Flags
 	distUrl: cli.StringFlag{
 		Name:  url,
-		Usage: "[Optional] JFrog Distribution URL.` `",
+		Usage: "[Optional] JFrog Distribution URL. (example: https://acme.jfrog.io/distribution)` `",
 	},
 	rbDryRun: cli.BoolFlag{
 		Name:  dryRun,
@@ -1293,7 +1305,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	countryCodes: cli.StringFlag{
 		Name:  countryCodes,
-		Usage: "[Default: '*'] Semicolon-separated list of wildcard filters for site country codes.` `",
+		Usage: "[Default: '*'] List of semicolon-separated(;) wildcard filters for site country codes.` `",
 	},
 	sync: cli.BoolFlag{
 		Name:  sync,
@@ -1309,13 +1321,13 @@ var flagsMap = map[string]cli.Flag{
 	},
 	targetProps: cli.StringFlag{
 		Name:  targetProps,
-		Usage: "[Optional] The list of properties, in the form of key1=value1;key2=value2,..., to be added to the artifacts after distribution of the release bundle.` `",
+		Usage: "[Optional] List of semicolon-separated(;) properties, in the form of \"key1=value1;key2=value2;...\" to be added to the artifacts after distribution of the release bundle.` `",
 	},
 
 	// Xray's commands Flags
 	xrUrl: cli.StringFlag{
 		Name:  url,
-		Usage: "[Optional] JFrog Xray URL.` `",
+		Usage: "[Optional] JFrog Xray URL. (example: https://acme.jfrog.io/xray)` `",
 	},
 	xrayScan: cli.StringFlag{
 		Name:  xrayScan,
@@ -1371,15 +1383,15 @@ var flagsMap = map[string]cli.Flag{
 	},
 	watches: cli.StringFlag{
 		Name:  watches,
-		Usage: "[Optional] A comma-separated list of Xray watches, to determine Xray's violations creation.` `",
+		Usage: "[Optional] A comma-separated(,) list of Xray watches, to determine Xray's violations creation.` `",
 	},
 	workingDirs: cli.StringFlag{
 		Name:  workingDirs,
-		Usage: "[Optional] A comma-separated list of relative working directories, to determine audit targets locations.` `",
+		Usage: "[Optional] A comma-separated(,) list of relative working directories, to determine audit targets locations.` `",
 	},
 	ExclusionsAudit: cli.StringFlag{
 		Name:  exclusions,
-		Usage: "[Default: *node_modules*;*target*;*venv*;*test*] List of exclusions separated by semicolons, utilized to skip sub-projects from undergoing an audit. These exclusions may incorporate the * and ? wildcards.` `",
+		Usage: "[Default: *node_modules*;*target*;*venv*;*test*] List of semicolon-separated(;) exclusions, utilized to skip sub-projects from undergoing an audit. These exclusions may incorporate the * and ? wildcards.` `",
 	},
 	ExtendedTable: cli.BoolFlag{
 		Name:  ExtendedTable,
@@ -1459,7 +1471,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	goPublishExclusions: cli.StringFlag{
 		Name:  exclusions,
-		Usage: "[Optional] Semicolon-separated list of exclusions. Exclusions can include the * and the ? wildcards.` `",
+		Usage: "[Optional] List of semicolon-separated(;) exclusions. Exclusions can include the * and the ? wildcards.` `",
 	},
 	rescan: cli.BoolFlag{
 		Name:  rescan,
@@ -1478,7 +1490,7 @@ var flagsMap = map[string]cli.Flag{
 	// Mission Control's commands Flags
 	mcUrl: cli.StringFlag{
 		Name:  url,
-		Usage: "[Optional] JFrog Mission Control URL.` `",
+		Usage: "[Optional] JFrog Mission Control URL. (example: https://acme.jfrog.io/mc)` `",
 	},
 	mcAccessToken: cli.StringFlag{
 		Name:  accessToken,
@@ -1501,27 +1513,27 @@ var flagsMap = map[string]cli.Flag{
 	// Config commands Flags
 	configPlatformUrl: cli.StringFlag{
 		Name:  url,
-		Usage: "[Optional] JFrog platform URL.` `",
+		Usage: "[Optional] JFrog platform URL. (example: https://acme.jfrog.io)` `",
 	},
 	configRtUrl: cli.StringFlag{
 		Name:  configRtUrl,
-		Usage: "[Optional] JFrog Artifactory URL.` `",
+		Usage: "[Optional] JFrog Artifactory URL. (example: https://acme.jfrog.io/artifactory)` `",
 	},
 	configDistUrl: cli.StringFlag{
 		Name:  configDistUrl,
-		Usage: "[Optional] JFrog Distribution URL.` `",
+		Usage: "[Optional] JFrog Distribution URL. (example: https://acme.jfrog.io/distribution)` `",
 	},
 	configXrUrl: cli.StringFlag{
 		Name:  configXrUrl,
-		Usage: "[Optional] JFrog Xray URL.` `",
+		Usage: "[Optional] JFrog Xray URL. (example: https://acme.jfrog.io/xray)` `",
 	},
 	configMcUrl: cli.StringFlag{
 		Name:  configMcUrl,
-		Usage: "[Optional] JFrog Mission Control URL.` `",
+		Usage: "[Optional] JFrog Mission Control URL. (example: https://acme.jfrog.io/mc)` `",
 	},
 	configPlUrl: cli.StringFlag{
 		Name:  configPlUrl,
-		Usage: "[Optional] JFrog Pipelines URL.` `",
+		Usage: "[Optional] JFrog Pipelines URL. (example: https://acme.jfrog.io/pipelines)` `",
 	},
 	configUser: cli.StringFlag{
 		Name:  user,
@@ -1547,10 +1559,6 @@ var flagsMap = map[string]cli.Flag{
 		Name:  Install,
 		Usage: "[Default: false] Set to true to install the completion script instead of printing it to the standard output.` `",
 	},
-	setupFormat: cli.StringFlag{
-		Name:   "format",
-		Hidden: true,
-	},
 	CreateRepo: cli.BoolFlag{
 		Name:  CreateRepo,
 		Usage: "[Default: false] Set to true to create the repository on the edge if it does not exist.` `",
@@ -1561,19 +1569,19 @@ var flagsMap = map[string]cli.Flag{
 	},
 	IncludeRepos: cli.StringFlag{
 		Name:  IncludeRepos,
-		Usage: "[Optional] A list of semicolon-separated repositories to include in the transfer. You can use wildcards to specify patterns for the repositories' names.` `",
+		Usage: "[Optional] List of semicolon-separated(;) repositories to include in the transfer. You can use wildcards to specify patterns for the repositories' names.` `",
 	},
 	ExcludeRepos: cli.StringFlag{
 		Name:  ExcludeRepos,
-		Usage: "[Optional] A list of semicolon-separated repositories to exclude from the transfer. You can use wildcards to specify patterns for the repositories' names.` `",
+		Usage: "[Optional] List of semicolon-separated(;) repositories to exclude from the transfer. You can use wildcards to specify patterns for the repositories' names.` `",
 	},
 	IncludeProjects: cli.StringFlag{
 		Name:  IncludeProjects,
-		Usage: "[Optional] A list of semicolon-separated JFrog Project keys to include in the transfer. You can use wildcards to specify patterns for the JFrog Project keys.` `",
+		Usage: "[Optional] List of semicolon-separated(;) JFrog Project keys to include in the transfer. You can use wildcards to specify patterns for the JFrog Project keys.` `",
 	},
 	ExcludeProjects: cli.StringFlag{
 		Name:  ExcludeProjects,
-		Usage: "[Optional] A list of semicolon-separated JFrog Projects to exclude from the transfer. You can use wildcards to specify patterns for the project keys.` `",
+		Usage: "[Optional] List of semicolon-separated(;) JFrog Projects to exclude from the transfer. You can use wildcards to specify patterns for the project keys.` `",
 	},
 	IgnoreState: cli.BoolFlag{
 		Name:  IgnoreState,
@@ -1627,9 +1635,9 @@ var flagsMap = map[string]cli.Flag{
 		Name:  PreChecks,
 		Usage: "[Default: false] Set to true to run pre-transfer checks.` `",
 	},
-	lcSync: cli.BoolFlag{
+	lcSync: cli.BoolTFlag{
 		Name:  Sync,
-		Usage: "[Default: false] Set to true to run synchronously.` `",
+		Usage: "[Default: true] Set to false to run asynchronously.` `",
 	},
 	lcProject: cli.StringFlag{
 		Name:  Project,
@@ -1647,7 +1655,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	lcSigningKey: cli.StringFlag{
 		Name:  SigningKey,
-		Usage: "[Mandatory] The GPG/RSA key-pair name given in Artifactory.` `",
+		Usage: "[Optional] The GPG/RSA key-pair name given in Artifactory. If the key isn't provided, the command creates or uses the default key.` `",
 	},
 	lcPathMappingPattern: cli.StringFlag{
 		Name:  PathMappingPattern,
@@ -1669,12 +1677,12 @@ var flagsMap = map[string]cli.Flag{
 	},
 	lcIncludeRepos: cli.StringFlag{
 		Name: IncludeRepos,
-		Usage: "[Optional] A list of semicolon-separated repositories to include in the promotion. If this property is left undefined, all repositories (except those specifically excluded) are included in the promotion. " +
+		Usage: "[Optional] List of semicolon-separated(;) repositories to include in the promotion. If this property is left undefined, all repositories (except those specifically excluded) are included in the promotion. " +
 			"If one or more repositories are specifically included, all other repositories are excluded.` `",
 	},
 	lcExcludeRepos: cli.StringFlag{
 		Name:  ExcludeRepos,
-		Usage: "[Optional] A list of semicolon-separated repositories to exclude from the promotion.` `",
+		Usage: "[Optional] List of semicolon-separated(;) repositories to exclude from the promotion.` `",
 	},
 	atcProject: cli.StringFlag{
 		Name:  Project,
@@ -1686,7 +1694,7 @@ var flagsMap = map[string]cli.Flag{
 	},
 	atcGroups: cli.StringFlag{
 		Name: Groups,
-		Usage: "[Optional] A list of comma-separated groups for the access token to be associated with. " +
+		Usage: "[Optional] A list of comma-separated(,) groups for the access token to be associated with. " +
 			"This is only available for administrators.` `",
 	},
 	atcScope: cli.StringFlag{
@@ -1734,7 +1742,7 @@ var commandFlags = map[string][]string{
 		ClientCertKeyPath, specFlag, specVars, buildName, buildNumber, module, uploadExclusions, deb,
 		uploadRecursive, uploadFlat, uploadRegexp, retries, retryWaitTime, dryRun, uploadExplode, symlinks, includeDirs,
 		failNoOp, threads, uploadSyncDeletes, syncDeletesQuiet, InsecureTls, detailedSummary, Project,
-		uploadAnt, uploadArchive, uploadMinSplit, uploadSplitCount,
+		uploadAnt, uploadArchive, uploadMinSplit, uploadSplitCount, ChunkSize,
 	},
 	Download: {
 		url, user, password, accessToken, sshPassphrase, sshKeyPath, serverId, ClientCertPath,
@@ -1814,6 +1822,12 @@ var commandFlags = map[string][]string{
 		url, user, password, accessToken, sshPassphrase, sshKeyPath, serverId, refs, glcRepo, glcDryRun,
 		glcQuiet, InsecureTls, retries, retryWaitTime,
 	},
+	CocoapodsConfig: {
+		global, serverIdResolve, repoResolve,
+	},
+	SwiftConfig: {
+		global, serverIdResolve, repoResolve,
+	},
 	MvnConfig: {
 		global, serverIdResolve, serverIdDeploy, repoResolveReleases, repoResolveSnapshots, repoDeployReleases, repoDeploySnapshots, includePatterns, excludePatterns, UseWrapper,
 	},
@@ -1829,7 +1843,7 @@ var commandFlags = map[string][]string{
 	},
 	Docker: {
 		buildName, buildNumber, module, Project,
-		serverId, skipLogin, threads, detailedSummary, watches, repoPath, licenses, xrOutput, fail, ExtendedTable, BypassArchiveLimits, MinSeverity, FixableOnly,
+		serverId, skipLogin, threads, detailedSummary, watches, repoPath, licenses, xrOutput, fail, ExtendedTable, BypassArchiveLimits, MinSeverity, FixableOnly, vuln,
 	},
 	DockerPush: {
 		buildName, buildNumber, module, Project,
@@ -1873,7 +1887,7 @@ var commandFlags = map[string][]string{
 		global, serverIdResolve, repoResolve, nugetV2,
 	},
 	Nuget: {
-		buildName, buildNumber, module, Project,
+		buildName, buildNumber, module, Project, allowInsecureConnections,
 	},
 	DotnetConfig: {
 		global, serverIdResolve, repoResolve, nugetV2,
@@ -1897,6 +1911,9 @@ var commandFlags = map[string][]string{
 		namespace, provider, tag, exclusions,
 		buildName, buildNumber, module, Project,
 	},
+	Twine: {
+		buildName, buildNumber, module, Project,
+	},
 	TransferConfig: {
 		Force, Verbose, IncludeRepos, ExcludeRepos, SourceWorkingDir, TargetWorkingDir, PreChecks,
 	},
@@ -1911,13 +1928,13 @@ var commandFlags = map[string][]string{
 		serverId,
 	},
 	PipConfig: {
-		global, serverIdResolve, repoResolve,
+		global, serverIdResolve, serverIdDeploy, repoResolve, repoDeploy,
 	},
 	PipInstall: {
 		buildName, buildNumber, module, Project,
 	},
 	PipenvConfig: {
-		global, serverIdResolve, repoResolve,
+		global, serverIdResolve, serverIdDeploy, repoResolve, repoDeploy,
 	},
 	PipenvInstall: {
 		buildName, buildNumber, module, Project,
@@ -2019,6 +2036,13 @@ var commandFlags = map[string][]string{
 		platformUrl, user, password, accessToken, serverId, deleteQuiet, lcDryRun, DistRules, site, city, countryCodes,
 		lcSync, maxWaitMinutes, lcProject,
 	},
+	ReleaseBundleExport: {
+		platformUrl, user, password, accessToken, serverId, lcPathMappingTarget, lcPathMappingPattern, Project,
+		downloadMinSplit, downloadSplitCount,
+	},
+	ReleaseBundleImport: {
+		user, password, accessToken, serverId, platformUrl,
+	},
 	// Mission Control's commands
 	McConfig: {
 		mcUrl, mcAccessToken, mcInteractive,
@@ -2047,9 +2071,6 @@ var commandFlags = map[string][]string{
 		Install,
 	},
 	// CLI base commands
-	Setup: {
-		setupFormat,
-	},
 	Intro: {},
 	// Pipelines commands
 	Status: {
