@@ -4,11 +4,12 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"github.com/jfrog/jfrog-cli-core/v2/artifactory/utils/commandsummary"
 	"io"
 	"net/http"
 	"os"
-	"path"
 	"path/filepath"
+	"strconv"
 	"strings"
 	"time"
 
@@ -124,7 +125,7 @@ func PrintBriefSummaryReport(success, failed int, failNoOp bool, originalErr err
 func PrintDeploymentView(reader *content.ContentReader) error {
 	tree := artifactoryUtils.NewFileTree()
 	for transferDetails := new(clientutils.FileTransferDetails); reader.NextRecord(transferDetails) == nil; transferDetails = new(clientutils.FileTransferDetails) {
-		tree.AddFile(transferDetails.TargetPath)
+		tree.AddFile(transferDetails.TargetPath, "")
 	}
 	if err := reader.GetError(); err != nil {
 		return err
@@ -253,6 +254,50 @@ func CreateBuildInfoSummaryReportString(success, failed int, sha256 string, err
 	return clientutils.IndentJson(buildInfoSummaryContent), mErr
 }
 
+func CreateDownloadConfiguration(c *cli.Context) (downloadConfiguration *artifactoryUtils.DownloadConfiguration, err error) {
+	downloadConfiguration = new(artifactoryUtils.DownloadConfiguration)
+	downloadConfiguration.MinSplitSize, err = getMinSplit(c, DownloadMinSplitKb)
+	if err != nil {
+		return nil, err
+	}
+	downloadConfiguration.SplitCount, err = getSplitCount(c, DownloadSplitCount, DownloadMaxSplitCount)
+	if err != nil {
+		return nil, err
+	}
+	downloadConfiguration.Threads, err = GetThreadsCount(c)
+	if err != nil {
+		return nil, err
+	}
+	downloadConfiguration.SkipChecksum = c.Bool("skip-checksum")
+	downloadConfiguration.Symlink = true
+	return
+}
+
+func CreateUploadConfiguration(c *cli.Context) (uploadConfiguration *artifactoryUtils.UploadConfiguration, err error) {
+	uploadConfiguration = new(artifactoryUtils.UploadConfiguration)
+	uploadConfiguration.MinSplitSizeMB, err = getMinSplit(c, UploadMinSplitMb)
+	if err != nil {
+		return nil, err
+	}
+	uploadConfiguration.ChunkSizeMB, err = getUploadChunkSize(c, UploadChunkSizeMb)
+	if err != nil {
+		return nil, err
+	}
+	uploadConfiguration.SplitCount, err = getSplitCount(c, UploadSplitCount, UploadMaxSplitCount)
+	if err != nil {
+		return nil, err
+	}
+	uploadConfiguration.Threads, err = GetThreadsCount(c)
+	if err != nil {
+		return nil, err
+	}
+	uploadConfiguration.Deb, err = getDebFlag(c)
+	if err != nil {
+		return
+	}
+	return
+}
+
 func PrintHelpAndReturnError(msg string, context *cli.Context) error {
 	return commonCliUtils.PrintHelpAndReturnError(msg, GetPrintCurrentCmdHelp(context))
 }
@@ -356,21 +401,32 @@ func handleSecretInput(c *cli.Context, stringFlag, stdinFlag string) (secret str
 	return commonCliUtils.HandleSecretInput(stringFlag, c.String(stringFlag), stdinFlag, c.Bool(stdinFlag))
 }
 
-func GetSpec(c *cli.Context, isDownload bool) (specFiles *speccore.SpecFiles, err error) {
+func GetSpec(c *cli.Context, isDownload, overrideFieldsIfSet bool) (specFiles *speccore.SpecFiles, err error) {
 	specFiles, err = speccore.CreateSpecFromFile(c.String("spec"), coreutils.SpecVarsStringToMap(c.String("spec-vars")))
 	if err != nil {
 		return nil, err
 	}
-	// Override spec with CLI options
-	for i := 0; i < len(specFiles.Files); i++ {
-		if isDownload {
-			specFiles.Get(i).Pattern = strings.TrimPrefix(specFiles.Get(i).Pattern, "/")
-		}
-		OverrideFieldsIfSet(specFiles.Get(i), c)
+	if isDownload {
+		trimPatternPrefix(specFiles)
+	}
+	if overrideFieldsIfSet {
+		overrideSpecFields(c, specFiles)
 	}
 	return
 }
 
+func overrideSpecFields(c *cli.Context, specFiles *speccore.SpecFiles) {
+	for i := 0; i < len(specFiles.Files); i++ {
+		OverrideFieldsIfSet(specFiles.Get(i), c)
+	}
+}
+
+func trimPatternPrefix(specFiles *speccore.SpecFiles) {
+	for i := 0; i < len(specFiles.Files); i++ {
+		specFiles.Get(i).Pattern = strings.TrimPrefix(specFiles.Get(i).Pattern, "/")
+	}
+}
+
 func GetFileSystemSpec(c *cli.Context) (fsSpec *speccore.SpecFiles, err error) {
 	fsSpec, err = speccore.CreateSpecFromFile(c.String("spec"), coreutils.SpecVarsStringToMap(c.String("spec-vars")))
 	if err != nil {
@@ -579,7 +635,7 @@ func CreateArtifactoryDetailsByFlags(c *cli.Context) (*coreConfig.ServerDetails,
 		return nil, err
 	}
 	if artDetails.ArtifactoryUrl == "" {
-		return nil, errors.New("the --url option is mandatory")
+		return nil, errors.New("no JFrog Artifactory URL specified, either via the --url flag or as part of the server configuration")
 	}
 	return artDetails, nil
 }
@@ -634,25 +690,31 @@ func CheckNewCliVersionAvailable(currentVersion string) (warningMessage string,
 	return
 }
 
+func GetDetailedSummary(c *cli.Context) bool {
+	return c.Bool("detailed-summary") || commandsummary.ShouldRecordSummary()
+}
+
+// Check if the latest CLI version should be checked via the GitHub API to let the user know if a newer version is available.
+// To avoid checking this for every run, we check only if the last check was more than 6 hours ago.
+// Also, if the user set the JFROG_CLI_AVOID_NEW_VERSION_WARNING environment variable to true, we won't check.
 func shouldCheckLatestCliVersion() (shouldCheck bool, err error) {
 	if strings.ToLower(os.Getenv(JfrogCliAvoidNewVersionWarning)) == "true" {
 		return
 	}
-	homeDir, err := coreutils.GetJfrogHomeDir()
+	latestVersionCheckTime, err := getLatestCliVersionCheckTime()
 	if err != nil {
 		return
 	}
-	indicatorFile := path.Join(homeDir, "Latest_Cli_Version_Check_Indicator")
-	fileInfo, err := os.Stat(indicatorFile)
-	if err != nil && !os.IsNotExist(err) {
-		err = fmt.Errorf("couldn't get indicator file %s info: %s", indicatorFile, err.Error())
-		return
-	}
-	if err == nil && (time.Now().UnixMilli()-fileInfo.ModTime().UnixMilli()) < LatestCliVersionCheckInterval.Milliseconds() {
+	timeNow := time.Now().UnixMilli()
+	if latestVersionCheckTime != nil &&
+		(timeNow-*latestVersionCheckTime) < LatestCliVersionCheckInterval.Milliseconds() {
 		// Timestamp file exists and updated less than 6 hours ago, therefor no need to check version again
 		return
 	}
-	return true, os.WriteFile(indicatorFile, []byte{}, 0666)
+	if err = setCliLatestVersionCheckTime(timeNow); err != nil {
+		return
+	}
+	return true, nil
 }
 
 func getLatestCliVersionFromGithubAPI() (githubVersionInfo githubResponse, err error) {
@@ -682,8 +744,7 @@ func doHttpRequest(client *http.Client, req *http.Request) (resp *http.Response,
 	}
 	defer func() {
 		if resp != nil && resp.Body != nil {
-			e := errorutils.CheckError(resp.Body.Close())
-			err = errors.Join(err, e)
+			err = errors.Join(err, errorutils.CheckError(resp.Body.Close()))
 		}
 	}()
 	body, err = io.ReadAll(resp.Body)
@@ -695,3 +756,68 @@ func GetProject(c *cli.Context) string {
 	projectKey := c.String("project")
 	return getOrDefaultEnv(projectKey, coreutils.Project)
 }
+
+func getSplitCount(c *cli.Context, defaultSplitCount, maxSplitCount int) (splitCount int, err error) {
+	splitCount = defaultSplitCount
+	err = nil
+	if c.String("split-count") != "" {
+		splitCount, err = strconv.Atoi(c.String("split-count"))
+		if err != nil {
+			err = errors.New("The '--split-count' option should have a numeric value. " + GetDocumentationMessage())
+		}
+		if splitCount > maxSplitCount {
+			err = errors.New("The '--split-count' option value is limited to a maximum of " + strconv.Itoa(maxSplitCount) + ".")
+		}
+		if splitCount < 0 {
+			err = errors.New("the '--split-count' option cannot have a negative value")
+		}
+	}
+	return
+}
+
+func getMinSplit(c *cli.Context, defaultMinSplit int64) (minSplitSize int64, err error) {
+	minSplitSize = defaultMinSplit
+	if c.String(MinSplit) != "" {
+		minSplitSize, err = strconv.ParseInt(c.String(MinSplit), 10, 64)
+		if err != nil {
+			err = errors.New("The '--min-split' option should have a numeric value. " + GetDocumentationMessage())
+			return 0, err
+		}
+	}
+
+	return minSplitSize, nil
+}
+
+func getUploadChunkSize(c *cli.Context, defaultChunkSize int64) (chunkSize int64, err error) {
+	chunkSize = defaultChunkSize
+	if c.String(ChunkSize) != "" {
+		chunkSize, err = strconv.ParseInt(c.String(ChunkSize), 10, 64)
+		if err != nil {
+			err = fmt.Errorf("the '--%s' option should have a numeric value. %s", ChunkSize, GetDocumentationMessage())
+			return 0, err
+		}
+	}
+
+	return chunkSize, nil
+}
+
+func getDebFlag(c *cli.Context) (deb string, err error) {
+	deb = c.String("deb")
+	slashesCount := strings.Count(deb, "/") - strings.Count(deb, "\\/")
+	if deb != "" && slashesCount != 2 {
+		return "", errors.New("the --deb option should be in the form of distribution/component/architecture")
+	}
+	return deb, nil
+}
+
+// ExtractBoolFlagFromArgs Extracts a boolean flag from the args and removes it from the slice.
+func ExtractBoolFlagFromArgs(filteredArgs *[]string, flagName string) (value bool, err error) {
+	var flagIndex int
+	var boolFlag bool
+	flagIndex, boolFlag, err = coreutils.FindBooleanFlag("--"+flagName, *filteredArgs)
+	if err != nil {
+		return false, err
+	}
+	coreutils.RemoveFlagFromCommand(filteredArgs, flagIndex, flagIndex)
+	return boolFlag, nil
+}
